;; Generated package description from jgraph-mode.el  -*- no-byte-compile: t -*-
(define-package "jgraph-mode" "1.1.0.20220620.85420" "Major mode for Jgraph files" '((cl-lib "0.5")) :commit "62ce4c369f4c9eae0b6aed18f4039b6a8f43de80" :url "https://elpa.gnu.org/packages/jgraph-mode.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("tex" "wp"))
